#include "Linebuffer.h"

#if ARDUINO >= 100
#include "Arduino.h"
#else
#include "WProgram.h"
#endif

/*
 * MonoLinebuffer class methods
 */

MonoLinebuffer::MonoLinebuffer()
{
  //
}

bool MonoLinebuffer::writePixelToBuffer(uint16_t pixelPosition, bool isWhite)
{
  if (pixelPosition < lcdPixelWidth)
  {
    uint8_t currentByte = pixelPosition / 8;
    uint8_t bitShift = 7 - (pixelPosition % 8);
    if (isWhite)
    {
      buffer[currentByte] |= (1 << bitShift);
    }
    else
    {
      buffer[currentByte] &= ~(1 << bitShift);
    }
    return true;
  }
  else
  {
    return false;
  }
}

bool MonoLinebuffer::writeByteToBuffer(uint8_t bytePosition, uint8_t byteContents)
{
  if (bytePosition < bufferSize)
  {
    buffer[bytePosition] = byteContents;
    return true;
  }
  else
  {
    return false;
  }
}

void MonoLinebuffer::clearBuffer()
{
  for (uint8_t i = 0; i < bufferSize; i++)
  {
    buffer[i] = 0xFF;
  }
}

void MonoLinebuffer::setBufferBlack()
{
  for (uint8_t i = 0; i < bufferSize; i++)
  {
    buffer[i] = 0x00;
  }
}

void MonoLinebuffer::setBufferWhite()
{
  clearBuffer();
}

const uint8_t *const MonoLinebuffer::getPointerToBuffer()
{
  return pBuffer;
}
