#ifndef _LINEBUFFER_LIB_H
#define _LINEBUFFER_LIB_H

#if ARDUINO >= 100
#include "Arduino.h"
#else
#include "WProgram.h"
#endif

/*
 * File contains two classes implementing linebuffers for the Sharp Memory LCD
 * MonoLinebuffer for all monochrome Memory LCDs
 * ColourLinebuffer for the single model of RGB colour Memory LCD
 * 
 * ATTENTION: The class MonoLinebuffer requires editing before use in order
 * to match it to the particular LCD model being used
 */

class MonoLinebuffer
{
public:
  MonoLinebuffer();
  bool writePixelToBuffer(uint16_t pixelPosition, bool isWhite);
  bool writeByteToBuffer(uint8_t bytePosition, uint8_t byteContents);
  void clearBuffer();
  void setBufferBlack();
  void setBufferWhite();
  const uint8_t *const getPointerToBuffer();

private:
/*
 * START EDITING - COMMENT OR UNCOMMENT TO SUIT YOUR MODEL OF MEMORY LCD
 * 
 * Array size 12 for a 96 pixel wide LCD
 * Array size 16 for a 128 pixel wide LCD
 * Array size 50 for a 400 pixel wide LCD
*/
  static const uint16_t lcdPixelWidth = 144;
  static const uint8_t bufferSize = 18;
  uint8_t buffer[bufferSize] = {0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF};
 
  uint8_t *const pBuffer = buffer;
};

#endif