#ifndef _MEMORY_LCD_LIB_H
#define _MEMORY_LCD_LIB_H

#if ARDUINO >= 100
#include "Arduino.h"
#else
#include "WProgram.h"
#endif

#include <SPI.h>
#include <SpiRAM.h>

// Memory LCD pixel dimensions - ALTER ACCORDING TO YOUR PARTICULAR LCD MODEL
#define LCDWIDTH (144)
#define LCDHEIGHT (168)

#define DISPWIDTH (96)
#define DISPHEIGHT (128)

// Delay constants for LCD timing   // (Datasheet values)
#define PWRUP_DISP_DELAY 40     // (>30us)
#define PWRUP_EXTCOMIN_DELAY 40 // (>30us)
#define SCS_HIGH_DELAY 3        // (>3us)
#define SCS_LOW_DELAY 1         // (>1us)
#define INTERFRAME_DELAY 1      // (>1us)

class MemoryLCD
{
public:
  enum displayType
  {
    mono = 1,
    colour = 3,
    color = 3
  };
  MemoryLCD(const uint8_t SCSpin, const uint8_t SIpin, const uint8_t SCLKpin, const uint8_t DISPpin, const uint8_t EXTCOMINpin, const uint8_t RAMCSpin, const boolean useEXTCOMIN, displayType d);
  void begin();
  void end();
  // Write data direct to screen
  void dispMultiLines(const uint8_t *const data, const uint8_t lineNumber, const uint8_t numLines = 1);

  

  void writeFrameBufferToDisplay();
  // clear functions
  void clearDisplay();

  void drawPixel(uint16_t x, uint16_t y, uint32_t color);
  void drawBitmap(uint8_t x,uint8_t y,const uint8_t *pBmp, uint8_t chWidth, uint8_t chHeight);
  void drawChar1616(uint8_t x,uint8_t y,uint8_t chChar);
  void drawChar3216(uint8_t x, uint8_t y, uint8_t chChar);
  void drawString(uint8_t x, uint8_t y, const char *pString, uint8_t Size, uint8_t Mode);
  void drawChar(uint8_t x, uint8_t y, uint8_t acsii, uint8_t size, uint8_t mode);

  // turn display on/off
  void turnOff();
  void turnOn();
  // return display parameters
  int getLcdWidth() const;
  int getLcdHeight() const;
  // VCOM control - NOT YET PROPERLY IMPLEMENTED
  void softToggleVCOM();
  void hardToggleVCOM();

private:
  // variables
  uint8_t commandByte;
  uint8_t vcomByte;
  const uint8_t DISP;
  const uint8_t SCS;
  const uint8_t SI;
  const uint8_t SCLK;
  const uint8_t EXTCOMIN;
  const uint8_t RAMCS;
  const byte colourDepth;
  const boolean enablePWM;
  boolean EXTCOMIN_PIN_STATE;
  unsigned int pwm_interrupt_counter;
  uint8_t lineBuffer[LCDWIDTH / 8];
  //uint8_t frameBuffer[LCDWIDTH / 8 * LCDHEIGHT];
  uint8_t savedSpiControlRegister; // AVR SPI regsiter handling
  SPISettings lcdSpiSettings;
  // member functions
  const uint8_t reverseBitOrder(const uint8_t b);

  SpiRAM sRam;
  void clearRam(void);
  uint8_t modBit;
  uint8_t modByte;
};

#endif
