#if ARDUINO >= 100
#include "Arduino.h"
#else
#include "WProgram.h"
#endif
#include <SPI.h>
#include <avr/pgmspace.h>
#include <SpiRAM.h>
#include "MemoryLCD.h"
#include "Linebuffer.h"
#include "ugui.h"
#include "resources.h"

// ---------------------------------------------------------------------------
// Variables for Arduino pin assignments: DUEMILANOVE
// ---------------------------------------------------------------------------

const uint8_t SPI_MOSI = 11;    // Do not change - hardware SPI MOSI pin
const uint8_t SPI_SCLK = 13;    // Do not change - hardware SPI CLK pin
const uint8_t SPI_MISO = 12;    // Do not change - hardware SPI MISO pin

const uint8_t LCD_EXTCOMIN = 6; // Can use any pin 
const uint8_t LCD_SCS = 7;      // Can use any pin except dedicated SPI SS pin 
const uint8_t LCD_DISP = 8;     // Can use any pin                       
const uint8_t RAMCS = 9;        // Can use any pin except dedicated SPI SS pin 

// ---------------------------------------------------------------------------
// Variables assignments & initialisations:
// ---------------------------------------------------------------------------

// Create linebuffer to write display data to
MonoLinebuffer lBuffer;

// Memory LCD related variables
MemoryLCD memLcd(LCD_SCS, SPI_MOSI, SPI_SCLK, LCD_DISP, LCD_EXTCOMIN, RAMCS, true, MemoryLCD::mono);
uint16_t lcdWidth;
uint16_t lcdHeight;

// Memory LCD interrupt service routine for hardware EXTCOMIN toggle
SIGNAL(TIMER0_COMPA_vect)
{
  memLcd.hardToggleVCOM();
}

UG_GUI gui;


void warpWritePixelToFrameBuffer(int16_t x, int16_t y, uint32_t color) { 
  memLcd.drawPixel(x, y, (uint32_t)color);
}

void setup()
{
  // Open serial communications and wait for port to open:
  Serial.begin(9600);

  // Initialise Memory LCD
  // clearDisplay() is important to erase the random pixel pattern displayed when power is first applied to the LCD.
  memLcd.begin();
  memLcd.clearDisplay();
  lcdWidth = memLcd.getLcdWidth();
  lcdHeight = memLcd.getLcdHeight();

  UG_Init(&gui, warpWritePixelToFrameBuffer, 144, 168);
  // Wait a while (optional - allows time to open serial console, if needed)
  delay(1000);
} // end of setup

void loop(void)
{
  // u'GUI draw some shape
  UG_DrawFrame(16, 16, 32, 32, C_BLACK);
  UG_FillFrame(48, 16, 64, 32, C_BLACK);
  UG_DrawCircle(88, 24, 8, C_BLACK);
  UG_FillCircle(120, 24, 8, C_BLACK);

  UG_DrawRoundFrame(16, 16 * 3, 16 + 16 * 3, 16 * 6, 10, C_BLACK);
  UG_DrawMesh(16 * 5, 16 * 3, 16 * 8, 16 * 6, C_BLACK);

  for (uint8_t i = 16; i < LCDWIDTH - 16; i++)
  {
    if (i % 4 == 0)
    {
      UG_DrawPixel(i, 16 * 7, C_BLACK);
    }
  }

  UG_DrawLine(16, 16 * 8, LCDWIDTH - 16, 16 * 8, C_BLACK);

  memLcd.writeFrameBufferToDisplay();
  
  delay(500);
  memLcd.clearDisplay();

  
  /* display images of bitmap matrix */
/*  
  memLcd.drawBitmap(0, 2, Signal816, 16, 8);
  memLcd.drawBitmap(24, 2, Bluetooth88, 8, 8);
  memLcd.drawBitmap(40, 2, Msg816, 16, 8);
  memLcd.drawBitmap(64, 2, GPRS88, 8, 8);
  memLcd.drawBitmap(90, 2, Alarm88, 8, 8);
  memLcd.drawBitmap(112, 2, Bat816, 16, 8);

  memLcd.drawString(0, 52, "MUSIC", 12, 0);
  memLcd.drawString(52, 52, "MENU", 12, 0);
  memLcd.drawString(98, 52, "PHONE", 12, 0);

  memLcd.drawChar3216(0, 16, '1');
  memLcd.drawChar3216(16, 16, '2');
  memLcd.drawChar3216(32, 16, ':');
  memLcd.drawChar3216(48, 16, '3');
  memLcd.drawChar3216(64, 16, '4');
  memLcd.drawChar3216(80, 16, ':');
  memLcd.drawChar3216(96, 16, '5');
  memLcd.drawChar3216(112, 16, '6');
*/
  memLcd.writeFrameBufferToDisplay();
  
  delay(500);
  memLcd.clearDisplay();
  
  // print pictrue
  const uint8_t *arr = gImage_pic;
  for (uint8_t y = 1; y < lcdHeight + 1; y++)
  {
    for (uint8_t lineBufferIndex = 0; lineBufferIndex < lcdWidth / 8; lineBufferIndex++)
    {
      lBuffer.writeByteToBuffer(lineBufferIndex, pgm_read_byte_near(gImage_pic + lineBufferIndex + (y - 1) * (lcdWidth / 8)));
    }
    memLcd.dispMultiLines(lBuffer.getPointerToBuffer(), y - 1);
    lBuffer.clearBuffer();
  }
  
  delay(500);
  lBuffer.clearBuffer();
  memLcd.clearDisplay();
}
